pub struct AwsEc2VpcDetails {
pub cidr_block_association_set: Option<Vec<CidrBlockAssociation>>,
pub dhcp_options_id: Option<String>,
pub ipv_6_cidr_block_association_set: Option<Vec<Ipv6CidrBlockAssociation>>,
pub state: Option<String>,
}Expand description
Details about an EC2 VPC.
Fields
cidr_block_association_set: Option<Vec<CidrBlockAssociation>>Information about the IPv4 CIDR blocks associated with the VPC.
dhcp_options_id: Option<String>The identifier of the set of Dynamic Host Configuration Protocol (DHCP) options that are associated with the VPC. If the default options are associated with the VPC, then this is default.
ipv_6_cidr_block_association_set: Option<Vec<Ipv6CidrBlockAssociation>>Information about the IPv6 CIDR blocks associated with the VPC.
state: Option<String>The current state of the VPC.