pub struct AwsIamAccessKeyDetails {
pub created_at: Option<String>,
pub principal_id: Option<String>,
pub principal_name: Option<String>,
pub principal_type: Option<String>,
pub status: Option<String>,
}Expand description
IAM access key details related to a finding.
Fields
created_at: Option<String>The creation date/time of the IAM access key related to a finding.
principal_id: Option<String>The ID of the principal associated with an access key.
principal_name: Option<String>The name of the principal.
principal_type: Option<String>The type of principal associated with an access key.
status: Option<String>The status of the IAM access key related to a finding.