pub struct AwsS3ObjectDetails {
pub content_type: Option<String>,
pub e_tag: Option<String>,
pub last_modified: Option<String>,
pub ssekms_key_id: Option<String>,
pub server_side_encryption: Option<String>,
pub version_id: Option<String>,
}Expand description
Details about an Amazon S3 object.
Fields
content_type: Option<String>A standard MIME type describing the format of the object data.
e_tag: Option<String>The opaque identifier assigned by a web server to a specific version of a resource found at a URL.
last_modified: Option<String>The date and time when the object was last modified.
ssekms_key_id: Option<String>The identifier of the AWS Key Management Service (AWS KMS) symmetric customer managed customer master key (CMK) that was used for the object.
server_side_encryption: Option<String>If the object is stored using server-side encryption, the value of the server-side encryption algorithm used when storing this object in Amazon S3.
version_id: Option<String>The version of the object.