pub struct AwsSqsQueueDetails {
pub dead_letter_target_arn: Option<String>,
pub kms_data_key_reuse_period_seconds: Option<i64>,
pub kms_master_key_id: Option<String>,
pub queue_name: Option<String>,
}Expand description
Data about a queue.
Fields
dead_letter_target_arn: Option<String>The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.
kms_data_key_reuse_period_seconds: Option<i64>The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling AWS KMS again.
kms_master_key_id: Option<String>The ID of an AWS managed customer master key (CMK) for Amazon SQS or a custom CMK.
queue_name: Option<String>The name of the new queue.