pub struct Compliance {
pub related_requirements: Option<Vec<String>>,
pub status: Option<String>,
pub status_reasons: Option<Vec<StatusReason>>,
}Expand description
Contains finding details that are specific to control-based findings. Only returned for findings generated from controls.
Fields
For a control, the industry or regulatory framework requirements that are related to the control. The check for that control is aligned with these requirements.
status: Option<String>The result of a standards check.
The valid values for Status are as follows.
-
-
PASSED- Standards check passed for all evaluated resources. -
WARNING- Some information is missing or this check is not supported for your configuration. -
FAILED- Standards check failed for at least one evaluated resource. -
NOTAVAILABLE- Check could not be performed due to a service outage, API error, or because the result of the AWS Config evaluation wasNOTAPPLICABLE. If the AWS Config evaluation result wasNOT_APPLICABLE, then after 3 days, Security Hub automatically archives the finding.
-
status_reasons: Option<Vec<StatusReason>>For findings generated from controls, a list of reasons behind the value of Status. For the list of status reason codes and their meanings, see Standards-related information in the ASFF in the AWS Security Hub User Guide.