pub struct AwsKmsKeyDetails {
pub aws_account_id: Option<String>,
pub creation_date: Option<f64>,
pub key_id: Option<String>,
pub key_manager: Option<String>,
pub key_state: Option<String>,
pub origin: Option<String>,
}Expand description
Contains metadata about a customer master key (CMK).
Fields
aws_account_id: Option<String>The twelve-digit account ID of the AWS account that owns the CMK.
creation_date: Option<f64>The date and time when the CMK was created.
key_id: Option<String>The globally unique identifier for the CMK.
key_manager: Option<String>The manager of the CMK. CMKs in your AWS account are either customer managed or AWS managed.
key_state: Option<String>The state of the CMK.
origin: Option<String>The source of the CMK's key material.
When this value is AWS_KMS, AWS KMS created the key material.
When this value is EXTERNAL, the key material was imported from your existing key management infrastructure or the CMK lacks key material.
When this value is AWS_CLOUDHSM, the key material was created in the AWS CloudHSM cluster associated with a custom key store.