pub struct AwsRdsDbInstanceDetails {Show 19 fields
pub associated_roles: Option<Vec<AwsRdsDbInstanceAssociatedRole>>,
pub ca_certificate_identifier: Option<String>,
pub db_cluster_identifier: Option<String>,
pub db_instance_class: Option<String>,
pub db_instance_identifier: Option<String>,
pub db_name: Option<String>,
pub db_instance_port: Option<i64>,
pub dbi_resource_id: Option<String>,
pub deletion_protection: Option<bool>,
pub endpoint: Option<AwsRdsDbInstanceEndpoint>,
pub engine: Option<String>,
pub engine_version: Option<String>,
pub iam_database_authentication_enabled: Option<bool>,
pub instance_create_time: Option<String>,
pub kms_key_id: Option<String>,
pub publicly_accessible: Option<bool>,
pub storage_encrypted: Option<bool>,
pub tde_credential_arn: Option<String>,
pub vpc_security_groups: Option<Vec<AwsRdsDbInstanceVpcSecurityGroup>>,
}Expand description
Contains the details of an Amazon RDS DB instance.
Fields
associated_roles: Option<Vec<AwsRdsDbInstanceAssociatedRole>>The AWS Identity and Access Management (IAM) roles associated with the DB instance.
ca_certificate_identifier: Option<String>The identifier of the CA certificate for this DB instance.
db_cluster_identifier: Option<String>If the DB instance is a member of a DB cluster, contains the name of the DB cluster that the DB instance is a member of.
db_instance_class: Option<String>Contains the name of the compute and memory capacity class of the DB instance.
db_instance_identifier: Option<String>Contains a user-supplied database identifier. This identifier is the unique key that identifies a DB instance.
db_name: Option<String>The meaning of this parameter differs according to the database engine you use.
MySQL, MariaDB, SQL Server, PostgreSQL
Contains the name of the initial database of this instance that was provided at create time, if one was specified when the DB instance was created. This same name is returned for the life of the DB instance.
Oracle
Contains the Oracle System ID (SID) of the created DB instance. Not shown when the returned parameters do not apply to an Oracle DB instance.
db_instance_port: Option<i64>Specifies the port that the DB instance listens on. If the DB instance is part of a DB cluster, this can be a different port than the DB cluster port.
dbi_resource_id: Option<String>The AWS Region-unique, immutable identifier for the DB instance. This identifier is found in AWS CloudTrail log entries whenever the AWS KMS key for the DB instance is accessed.
deletion_protection: Option<bool>Indicates whether the DB instance has deletion protection enabled.
When deletion protection is enabled, the database cannot be deleted.
endpoint: Option<AwsRdsDbInstanceEndpoint>Specifies the connection endpoint.
engine: Option<String>Provides the name of the database engine to use for this DB instance.
engine_version: Option<String>Indicates the database engine version.
iam_database_authentication_enabled: Option<bool>True if mapping of AWS Identity and Access Management (IAM) accounts to database accounts is enabled, and otherwise false.
IAM database authentication can be enabled for the following database engines.
-
For MySQL 5.6, minor version 5.6.34 or higher
-
For MySQL 5.7, minor version 5.7.16 or higher
-
Aurora 5.6 or higher
instance_create_time: Option<String>Provides the date and time the DB instance was created.
kms_key_id: Option<String>If StorageEncrypted is true, the AWS KMS key identifier for the encrypted DB instance.
publicly_accessible: Option<bool>Specifies the accessibility options for the DB instance.
A value of true specifies an Internet-facing instance with a publicly resolvable DNS name, which resolves to a public IP address.
A value of false specifies an internal instance with a DNS name that resolves to a private IP address.
storage_encrypted: Option<bool>Specifies whether the DB instance is encrypted.
tde_credential_arn: Option<String>The ARN from the key store with which the instance is associated for TDE encryption.
vpc_security_groups: Option<Vec<AwsRdsDbInstanceVpcSecurityGroup>>A list of VPC security groups that the DB instance belongs to.